@@ -37,7 +37,7 @@ DO NOT EVER RUN THIS TEST AGAINST A PRODUCTION DATABASE.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '#1.0.3#'
+__version__ = '1.04'
 
 
 import unittest
@@ -55,6 +55,16 @@ class TestNamedImport(unittest.TestCase):
     self.named_file = open(NAMED_FILE).read()
     self.maxDiff = None
 
+  def testScrubComments01(self):
+    self.assertEqual(iscpy.ScrubComments("/* */foobar"), "foobar")
+
+  def testScrubComments02(self):
+    self.assertEqual(iscpy.ScrubComments("/*\n*/foobar"), "foobar")
+
+  def testScrubComments03(self):
+    self.assertEqual(iscpy.ScrubComments("/*\n*\n*\n*/foobar"), "foobar")
+
+
   def testScrubComments(self):
     self.assertEqual(iscpy.ScrubComments(self.named_file),
                      'options {\ndirectory "/var/domain";\nrecursion yes;\n'
